package com.hcloud.microservice.goods.facade.clients;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.goods.facade.fallback.factory.GoodsBatchManageFallback;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchInfoForm;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

/**
 * @author xiezt
 */
@FeignClient(name = "goods-service" ,path = "/goods/batch",fallbackFactory = GoodsBatchManageFallback.class)
public interface GoodsBatchManagerService {

    /**
     * 分页查询商品批次记录
     * @param goodsBatchInfoForm
     * @return
     */
   @PostMapping("/queryGoodsBatchRecordByPage")
   ResultVO queryGoodsBatchRecordByPage(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm);

    /**
     * 添加商品批次记录
     * @param goodsBatchInfoForm
     * @return
     */
   @PostMapping("/addGoodsBatchRecord")
   ResultVO addGoodsBatchRecord(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm);

    /**
     * 编辑商品批次记录
     * @param goodsBatchInfoForm
     * @return
     */
   @PostMapping("/editGoodsBatchRecord")
   ResultVO editGoodsBatchRecord(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm);

    /**
     * 查询商品批次记录明细
     * @param guid
     * @return
     */
   @GetMapping("/getGoodsBatchRecordById")
   ResultVO getGoodsBatchRecordById(@RequestParam("id") String guid);

    /**
     * 删除商品批次记录
     * @param guid
     * @param orgGuid
     * @return
     */
   @GetMapping("/delGoodsBatchRecordById")
   ResultVO delGoodsBatchRecordById(@RequestParam("id") String guid,@RequestParam("orgGuid") String orgGuid);

    /**
     * 生成根据产品批次信息生成溯源码记录
     * @param goodsBatchInfoForm
     * @return
     */
   @PostMapping("/batchGoodsQRCode")
   ResultVO batchGoodsQRCode(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm);

    /**
     * 保存评价及评级信息
     * @param goodsBatchInfoForm
     * @return
     */
   @PostMapping("/saveFeedback")
   ResultVO saveAllFeedbackInfo(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm);

    /**
     * 查询用户商品批次评价信息
     * @param batchId
     * @param userId
     * @return
     */
   @GetMapping("getAllFeedback")
   ResultVO searchAllFeedbackInfo(@RequestParam("batchId") String batchId,@RequestParam("userId") String userId);

}
