package com.hcloud.microservice.goods.facade.clients;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.goods.facade.fallback.factory.GoodsQRCodeManageFallback;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeInfoForm;

import java.util.List;

import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

/**
 * @author xiezt
 */
@FeignClient(name = "goods-service",path = "/qrcode/info",fallbackFactory = GoodsQRCodeManageFallback.class )
public interface GoodsQRCodeManagerService {

    /**
     * 分页查询商品溯源码信息
     * @param goodsQRCodeInfoForm
     * @return
     */
    @PostMapping("/searchByPage")
    ResultVO searchGoodsQRCodeByPage(@RequestBody GoodsQRCodeInfoForm goodsQRCodeInfoForm);

    /**
     * 获取商品溯源码明细信息
     * @param guid
     * @return
     */
    @GetMapping("/getGoodsQRCodeById")
    ResultVO getGoodsQRCodeById(@RequestParam("id") String guid);

    /**
     * 删除商品溯源码信息
     * @param goodsQRCodeInfoForm
     * @return
     */
    @PostMapping("/delGoodsQRCodeById")
    ResultVO delGoodsQRCodeById(@RequestBody GoodsQRCodeInfoForm goodsQRCodeInfoForm);

    /**
     * 查询导出溯源码信息
     * @param guid
     * @return
     */
    @GetMapping("/searchGoodsQRCodeForExport")
    ResultVO searchGoodsQRCodeForExport(@RequestParam("id") String guid);

    /**
     * 通过二维码传输码查询溯源码信息
     * @param tokenStr
     * @return
     */
    @GetMapping("/searchByToken")
    ResultVO searchGoodsQRCodeInfoByTokenStr(@RequestParam("token") String tokenStr);

    /**
     * 通过二维码传输码预览溯源码信息
     * @param tokenStr
     * @return
     */
    @GetMapping("/getDetailByToken")
    ResultVO getGoodsQRCodeDetailInfoByToken(@RequestParam("token") String tokenStr);
    
    /**
     * 通过生成记录Id查询打印溯源码信息
     * @author lym
     * @param recordId
     * @return
     */
    @PostMapping("/getPrintDetail")
    ResultVO getPrintDetail(@RequestBody GoodsQRCodeInfoForm goodsQRCodeInfoForm);
    
    /**
     * 修改打印状态
     * @author lym
     * @param ids
     * @return
     */
    @PostMapping("/updateQRIsPrint")
    ResultVO updateQRIsPrint(@RequestBody List<String> ids);
}
