package com.hcloud.microservice.goods.facade.clients;

import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.goods.facade.entity.GoodsQRCodeRecord;
import com.hcloud.microservice.goods.facade.fallback.factory.GoodsQRCodeRecordManageFallback;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeRecordForm;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeRecordStatForm;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @author xiezt
 */
@FeignClient(name = "goods-service" ,path = "/qrcode/record",fallbackFactory = GoodsQRCodeRecordManageFallback.class)
public interface GoodsQRCodeRecordManagerService {

    /**
     * 分页查询溯源码生成记录
     * @param goodsQRCodeRecordForm
     * @return
     */
    @PostMapping("/searchByPage")
    ResultVO searchGoodsQRCodeRecordByPage(@RequestBody GoodsQRCodeRecordForm goodsQRCodeRecordForm);

    /**
     * 查询溯源码生成记录为导出
     * @param goodsQRCodeRecordForm
     * @return
     */
    @PostMapping("/searchForExport")
    ResultVO searchGoodsQRCodeRecordForExport(@RequestBody GoodsQRCodeRecordForm goodsQRCodeRecordForm);

    /**
     * 废除溯源码生成记录（逻辑删除）
     * @param goodsQRCodeRecordForm
     * @return
     */
    @PostMapping("/delGoodsQRCodeRecord")
    ResultVO delGoodsQRCodeRecord(@RequestBody GoodsQRCodeRecordForm goodsQRCodeRecordForm);

    /**
     * 通过recordId查询生成记录明细
     * @param goodsQRCodeRecordForm
     * @return
     */
    @GetMapping("/getGoodsQRCodeInfoByRecordId")
    ResultVO getGoodsQRCodeInfoByRecordId(@RequestBody GoodsQRCodeRecordForm goodsQRCodeRecordForm);

    /**
     * 物理删除溯源码生成记录
     * @param recordId
     * @return
     */
    @GetMapping("/delQRCodeInfoPhysical")
    ResultVO delQRCodeInfoPhysical(@RequestParam("recordId") String recordId);

    /**
     * 统计一年各月的扫码人数
     * @param goodsQRCodeRecordStatForm
     * @return
     */
    @PostMapping("/statOneYear")
    ResultVO statOneYearScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm);

    /**
     * 统计昨天和历史累计扫码人数
     * @param goodsQRCodeRecordStatForm
     * @return
     */
    @PostMapping("/statYesterdayAndAllTime")
    ResultVO statYesterdayAndAllTimeScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm);

    /**
     * 统计一天24个整点每个整点时段的扫码人数
     * @param goodsQRCodeRecordStatForm
     * @return
     */
    @PostMapping("/statOneDayAllHours")
    ResultVO statOneDayAllHoursScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm);

    /**
     * 统计一周7天每天的扫码人数
     * @param goodsQRCodeRecordStatForm
     * @return
     */
    @PostMapping("/statOneWeekSevenDay")
    ResultVO statOneWeekSevenDayScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm);

    /**
     * 统计本月每天的扫码人数
     * @param goodsQRCodeRecordStatForm
     * @return
     */
    @PostMapping("/statOneMonthAllDays")
    ResultVO statOneMonthAllDaysScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm);
}
