package com.hcloud.microservice.goods.facade.fallback.factory;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microservice.goods.facade.fallback.GoodsFeedbackFactory;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchFeedbackForm;
import feign.hystrix.FallbackFactory;
import org.springframework.stereotype.Component;

/**
 * @author xiezt
 */
@Component
public class GoodsFeedbackFallback implements FallbackFactory<GoodsFeedbackFactory> {

    @Override
    public GoodsFeedbackFactory create(Throwable cause) {
        return new GoodsFeedbackFactory(){
            /**
             * 分页查询商品评价信息
             *
             * @param gradeForm
             * @return
             */
            @Override
            public ResultVO searchGoodsFeedbackByPage(GoodsBatchFeedbackForm gradeForm) {
                return new ResultVO(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 获取用户评价信息
             *
             * @param userId
             * @param batchId
             * @return
             */
            @Override
            public ResultVO getGoodsFeedbackByUserId(String userId, String batchId) {
                return new ResultVO(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 保存用户评价信息
             *
             * @param gradeForm
             * @return
             */
            @Override
            public ResultVO saveGoodsFeedbackInfo(GoodsBatchFeedbackForm gradeForm) {
                return new ResultVO(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 批量删除用户评价
             *
             * @param gradeForm
             * @return
             */
            @Override
            public ResultVO delGoodsFeedbackInfo(GoodsBatchFeedbackForm gradeForm) {
                return new ResultVO(ResultEnum.SYS_BREAK_ERROR);
            }
        };
    }
}
